diff --git a/components/lib/breadcrumb/BreadcrumbItem.vue b/components/lib/breadcrumb/BreadcrumbItem.vue
index 6f530fbd3..6da7d2349 100755
--- a/components/lib/breadcrumb/BreadcrumbItem.vue
+++ b/components/lib/breadcrumb/BreadcrumbItem.vue
@@ -2,9 +2,9 @@
-
-
- {{ label() }}
+
+
+ {{ label() }}
diff --git a/components/lib/breadcrumb/style/BreadcrumbStyle.js b/components/lib/breadcrumb/style/BreadcrumbStyle.js
index 9b051ef71..c7e9bb391 100644
--- a/components/lib/breadcrumb/style/BreadcrumbStyle.js
+++ b/components/lib/breadcrumb/style/BreadcrumbStyle.js
@@ -66,8 +66,8 @@ const classes = {
separator: 'p-breadcrumb-separator',
item: ({ instance }) => ['p-breadcrumb-item', { 'p-disabled': instance.disabled() }],
itemLink: 'p-breadcrumb-item-link',
- icon: 'p-breadcrumb-item-icon',
- label: 'p-breadcrumb-item-label'
+ itemIcon: 'p-breadcrumb-item-icon',
+ itemLabel: 'p-breadcrumb-item-label'
};
export default BaseStyle.extend({
diff --git a/components/lib/datatable/style/DataTableStyle.js b/components/lib/datatable/style/DataTableStyle.js
index 098cd7100..8320fa1ff 100644
--- a/components/lib/datatable/style/DataTableStyle.js
+++ b/components/lib/datatable/style/DataTableStyle.js
@@ -657,7 +657,7 @@ const classes = {
filterConstraintSeparator: 'p-datatable-filter-constraint-separator',
filterOperator: 'p-datatable-filter-operator',
filterOperatorDropdown: 'p-datatable-filter-operator-dropdown',
- filterConstraints: 'p-datatable-filter-rule-list',
+ filterRuleList: 'p-datatable-filter-rule-list',
filterRule: 'p-datatable-filter-rule',
filterConstraintDropdown: 'p-datatable-filter-constraint-dropdown',
filterRemoveRuleButton: 'p-datatable-filter-remove-rule-button',
diff --git a/components/lib/dialog/Dialog.vue b/components/lib/dialog/Dialog.vue
index 87919b8f2..9a08c6723 100755
--- a/components/lib/dialog/Dialog.vue
+++ b/components/lib/dialog/Dialog.vue
@@ -14,17 +14,17 @@
v-if="maximizable"
:ref="maximizableRef"
:autofocus="focusableMax"
- :class="cx('maximizableButton')"
+ :class="cx('maximizeButton')"
@click="maximize"
:tabindex="maximizable ? '0' : '-1'"
:unstyled="unstyled"
v-bind="maximizeButtonProps"
- :pt="ptm('maximizableButton')"
+ :pt="ptm('maximizeButton')"
data-pc-group-section="headericon"
>
-
-
+
+
diff --git a/components/lib/dialog/style/DialogStyle.js b/components/lib/dialog/style/DialogStyle.js
index 9128d42c6..4c822e384 100644
--- a/components/lib/dialog/style/DialogStyle.js
+++ b/components/lib/dialog/style/DialogStyle.js
@@ -174,7 +174,7 @@ const classes = {
header: 'p-dialog-header',
title: 'p-dialog-title',
headerActions: 'p-dialog-header-actions',
- maximizableButton: 'p-dialog-maximize-button',
+ maximizeButton: 'p-dialog-maximize-button',
closeButton: 'p-dialog-close-button',
content: 'p-dialog-content',
footer: 'p-dialog-footer'
diff --git a/components/lib/galleria/GalleriaThumbnails.vue b/components/lib/galleria/GalleriaThumbnails.vue
index 5e15f2b11..ff91a9ea3 100755
--- a/components/lib/galleria/GalleriaThumbnails.vue
+++ b/components/lib/galleria/GalleriaThumbnails.vue
@@ -14,7 +14,7 @@
>
-
+
[
'p-galleria-thumbnail-item',
diff --git a/components/lib/megamenu/MegaMenuSub.vue b/components/lib/megamenu/MegaMenuSub.vue
index 8f4bd994d..ad1b2dcdd 100644
--- a/components/lib/megamenu/MegaMenuSub.vue
+++ b/components/lib/megamenu/MegaMenuSub.vue
@@ -25,7 +25,7 @@
-
+
{{ getItemLabel(processedItem) }}
diff --git a/components/lib/megamenu/style/MegaMenuStyle.js b/components/lib/megamenu/style/MegaMenuStyle.js
index 141aa47fe..6a117d0c0 100644
--- a/components/lib/megamenu/style/MegaMenuStyle.js
+++ b/components/lib/megamenu/style/MegaMenuStyle.js
@@ -316,7 +316,7 @@ const classes = {
itemContent: 'p-megamenu-item-content',
itemLink: 'p-megamenu-item-link',
itemIcon: 'p-megamenu-item-icon',
- label: 'p-megamenu-item-text',
+ itemLabel: 'p-megamenu-item-label',
submenuIcon: 'p-megamenu-submenu-icon',
panel: 'p-megamenu-panel',
grid: 'p-megamenu-grid',
diff --git a/components/lib/menu/Menuitem.vue b/components/lib/menu/Menuitem.vue
index 1bbb3d061..98d2013a3 100644
--- a/components/lib/menu/Menuitem.vue
+++ b/components/lib/menu/Menuitem.vue
@@ -16,7 +16,7 @@
- {{ label() }}
+ {{ label() }}
@@ -96,9 +96,9 @@ export default {
),
label: mergeProps(
{
- class: this.cx('label')
+ class: this.cx('itemLabel')
},
- this.getPTOptions('label')
+ this.getPTOptions('itemLabel')
)
};
}
diff --git a/components/lib/menu/style/MenuStyle.js b/components/lib/menu/style/MenuStyle.js
index 09372c113..42e3d5d06 100644
--- a/components/lib/menu/style/MenuStyle.js
+++ b/components/lib/menu/style/MenuStyle.js
@@ -114,7 +114,7 @@ const classes = {
itemContent: 'p-menu-item-content',
itemLink: 'p-menu-item-link',
itemIcon: 'p-menu-item-icon',
- label: 'p-menu-item-label'
+ itemLabel: 'p-menu-item-label'
};
export default BaseStyle.extend({
diff --git a/components/lib/panelmenu/PanelMenuSub.vue b/components/lib/panelmenu/PanelMenuSub.vue
index 107f5c6f8..38ff3f370 100755
--- a/components/lib/panelmenu/PanelMenuSub.vue
+++ b/components/lib/panelmenu/PanelMenuSub.vue
@@ -25,7 +25,7 @@
- {{ getItemLabel(processedItem) }}
+ {{ getItemLabel(processedItem) }} `
border-radius: ${dt('rounded.base')};
}
-.p-password-meter-value {
+.p-password-meter-label {
height: 100%;
width: 0;
transition: width 1s ease-in-out;
@@ -91,8 +91,8 @@ const classes = {
}
],
meter: 'p-password-meter',
- meterLabel: ({ instance }) => `p-password-meter-value ${instance.meter ? 'p-password-meter-' + instance.meter.strength : ''}`,
- info: 'p-password-meter-text'
+ meterLabel: ({ instance }) => `p-password-meter-label ${instance.meter ? 'p-password-meter-' + instance.meter.strength : ''}`,
+ meterText: 'p-password-meter-text'
};
export default BaseStyle.extend({
diff --git a/components/lib/speeddial/SpeedDial.vue b/components/lib/speeddial/SpeedDial.vue
index c4f60a416..f667519e0 100644
--- a/components/lib/speeddial/SpeedDial.vue
+++ b/components/lib/speeddial/SpeedDial.vue
@@ -29,11 +29,11 @@
v-if="isItemVisible(item)"
:id="`${id}_${index}`"
:aria-controls="`${id}_item`"
- :class="cx('menuitem', { id: `${id}_${index}` })"
+ :class="cx('item', { id: `${id}_${index}` })"
:style="getItemStyle(index)"
role="none"
:data-p-active="isItemActive(`${id}_${index}`)"
- v-bind="getPTOptions(`${id}_${index}`, 'menuitem')"
+ v-bind="getPTOptions(`${id}_${index}`, 'item')"
>
diff --git a/components/lib/treetable/style/TreeTableStyle.js b/components/lib/treetable/style/TreeTableStyle.js
index 1f201c9d3..5411b6a13 100644
--- a/components/lib/treetable/style/TreeTableStyle.js
+++ b/components/lib/treetable/style/TreeTableStyle.js
@@ -514,7 +514,7 @@ const classes = {
}
],
footer: 'p-treetable-footer',
- columnResizeHelper: 'p-treetable-column-resize-indicator'
+ columnResizeIndicator: 'p-treetable-column-resize-indicator'
};
const inlineStyles = {
diff --git a/components/lib/breadcrumb/Breadcrumb.d.ts b/components/lib/breadcrumb/Breadcrumb.d.ts
index ecae4d79e..9577a491c 100755
--- a/components/lib/breadcrumb/Breadcrumb.d.ts
+++ b/components/lib/breadcrumb/Breadcrumb.d.ts
@@ -67,13 +67,13 @@ export interface BreadcrumbPassThroughOptions {
*/
itemLink?: BreadcrumbPassThroughOptionType;
/**
* Used to pass attributes to the icon's DOM element.
*/
- icon?: BreadcrumbPassThroughOptionType;
+ itemIcon?: BreadcrumbPassThroughOptionType;
/**
* Used to pass attributes to the label's DOM element.
*/
- label?: BreadcrumbPassThroughOptionType;
+ itemLabel?: BreadcrumbPassThroughOptionType;
/**
* Used to pass attributes to the separator's DOM element.
*/
@@ -67,13 +67,13 @@ export interface BreadcrumbPassThroughOptions {
itemLink?: BreadcrumbPassThroughOptionType;
/**
- * Used to pass attributes to the icon's DOM element.
+ * Used to pass attributes to the item icon's DOM element.
*/
@@ -67,13 +67,13 @@ export interface BreadcrumbPassThroughOptions {
/**
- * Used to pass attributes to the label's DOM element.
+ * Used to pass attributes to the item label's DOM element.
*/
diff --git a/components/lib/dialog/Dialog.d.ts b/components/lib/dialog/Dialog.d.ts
index 59f734ee6..dcef13543 100755
--- a/components/lib/dialog/Dialog.d.ts
+++ b/components/lib/dialog/Dialog.d.ts
@@ -79,10 +79,10 @@ export interface DialogPassThroughOptions {
*/
headerActions?: DialogPassThroughOptionType;
/**
* Used to pass attributes to the maximizable Button component.
* @see {@link ButtonPassThroughOptions}
*/
- maximizableButton?: ButtonPassThroughOptions;
+ maximizeButton?: ButtonPassThroughOptions;
/**
* Used to pass attributes to the close Button component.
* @see {@link ButtonPassThroughOptions}
@@ -79,10 +79,10 @@ export interface DialogPassThroughOptions {
headerActions?: DialogPassThroughOptionType;
/**
- * Used to pass attributes to the maximizable Button component.
+ * Used to pass attributes to the maximize Button component.
* @see {@link ButtonPassThroughOptions}
*/
diff --git a/components/lib/galleria/Galleria.d.ts b/components/lib/galleria/Galleria.d.ts
index 32c213868..ce17535bd 100755
--- a/components/lib/galleria/Galleria.d.ts
+++ b/components/lib/galleria/Galleria.d.ts
@@ -151,9 +151,9 @@ export interface GalleriaPassThroughOptions {
*/
previousThumbnailIcon?: GalleriaPassThroughOptionType;
/**
* Used to pass attributes to the thumbnail items container's DOM element.
*/
- thumbnailItemsContainer?: GalleriaPassThroughOptionType;
+ thumbnailsViewport?: GalleriaPassThroughOptionType;
/**
* Used to pass attributes to the thumbnail items' DOM element.
*/
@@ -151,9 +151,9 @@ export interface GalleriaPassThroughOptions {
previousThumbnailIcon?: GalleriaPassThroughOptionType;
/**
- * Used to pass attributes to the thumbnail items container's DOM element.
+ * Used to pass attributes to the thumbnails viewport's DOM element.
*/
diff --git a/components/lib/megamenu/MegaMenu.d.ts b/components/lib/megamenu/MegaMenu.d.ts
index d6ec226a3..f403774a8 100755
--- a/components/lib/megamenu/MegaMenu.d.ts
+++ b/components/lib/megamenu/MegaMenu.d.ts
@@ -79,9 +79,9 @@ export interface MegaMenuPassThroughOptions {
*/
itemIcon?: MegaMenuPassThroughOptionType;
/**
* Used to pass attributes to the label's DOM element.
*/
- label?: MegaMenuPassThroughOptionType;
+ itemLabel?: MegaMenuPassThroughOptionType;
/**
* Used to pass attributes to the submenu icon's DOM element.
*/
@@ -79,9 +79,9 @@ export interface MegaMenuPassThroughOptions {
itemIcon?: MegaMenuPassThroughOptionType;
/**
- * Used to pass attributes to the label's DOM element.
+ * Used to pass attributes to the item label's DOM element.
*/
diff --git a/components/lib/menu/Menu.d.ts b/components/lib/menu/Menu.d.ts
index 346010592..3e7ff72e3 100755
--- a/components/lib/menu/Menu.d.ts
+++ b/components/lib/menu/Menu.d.ts
@@ -85,9 +85,9 @@ export interface MenuPassThroughOptions {
*/
itemIcon?: MenuPassThroughOptionType;
/**
* Used to pass attributes to the label's DOM element.
*/
- label?: MenuPassThroughOptionType;
+ itemLabel?: MenuPassThroughOptionType;
/**
* Used to pass attributes to the separator's DOM element.
*/
@@ -85,9 +85,9 @@ export interface MenuPassThroughOptions {
itemIcon?: MenuPassThroughOptionType;
/**
- * Used to pass attributes to the label's DOM element.
+ * Used to pass attributes to the item label's DOM element.
*/
diff --git a/components/lib/panelmenu/PanelMenu.d.ts b/components/lib/panelmenu/PanelMenu.d.ts
index 03abdd45a..ec3e2732b 100755
--- a/components/lib/panelmenu/PanelMenu.d.ts
+++ b/components/lib/panelmenu/PanelMenu.d.ts
@@ -117,9 +117,9 @@ export interface PanelMenuPassThroughOptions {
*/
itemIcon?: PanelMenuPassThroughOptionType;
/**
* Used to pass attributes to the label's DOM element.
*/
- label?: PanelMenuPassThroughOptionType;
+ itemLabel?: PanelMenuPassThroughOptionType;
/**
* Used to pass attributes to the submenu's DOM element.
*/
@@ -117,9 +117,9 @@ export interface PanelMenuPassThroughOptions {
itemIcon?: PanelMenuPassThroughOptionType;
/**
- * Used to pass attributes to the label's DOM element.
+ * Used to pass attributes to the item label's DOM element.
*/
diff --git a/components/lib/speeddial/SpeedDial.d.ts b/components/lib/speeddial/SpeedDial.d.ts
index 8a59a1760..1eb63d9c6 100644
--- a/components/lib/speeddial/SpeedDial.d.ts
+++ b/components/lib/speeddial/SpeedDial.d.ts
@@ -79,13 +79,13 @@ export interface SpeedDialPassThroughOptions {
*/
button?: ButtonPassThroughOptions;
/**
* Used to pass attributes to the menu's DOM element.
*/
- menu?: SpeedDialPassThroughOptionType;
+ list?: SpeedDialPassThroughOptionType;
/**
- * Used to pass attributes to the menu item's DOM element.
+ * Used to pass attributes to the item's DOM element.
*/
- menuitem?: SpeedDialPassThroughOptionType;
+ item?: SpeedDialPassThroughOptionType;
/**
* Used to pass attributes to the action's Button component.
* @see {@link ButtonPassThroughOptions}
@@ -79,13 +79,13 @@ export interface SpeedDialPassThroughOptions {
button?: ButtonPassThroughOptions;
/**
- * Used to pass attributes to the menu's DOM element.
+ * Used to pass attributes to the list's DOM element.
*/